
<!-- Quickstart
    install and run LN-Studio
    quickstart.md

Start
    projects
    projects.md
    create new graphs including macros, and yaml
    create.md
    run new graph, including LN-Studio and python 
    run.md
    short intro to multiprocessing and distributed computing
    multiprocessing.md

Extension
    create nodes
    node.md
    create interaction nodes
    draw.md
    insall new packages including nodes and bridges
    packages.md -->